summaryrefslogtreecommitdiffstats
path: root/container-search/src/main/java/com/yahoo/search/Query.java
diff options
context:
space:
mode:
authorJon Bratseth <bratseth@oath.com>2018-11-01 17:33:25 +0100
committergjoranv <gv@oath.com>2019-01-21 15:09:25 +0100
commitd0e23a4740c077690de8bcf8e2ca99e8049fb0be (patch)
tree34c9fc4556921e37088715064d0f61d1e7104735 /container-search/src/main/java/com/yahoo/search/Query.java
parent9ade75b7b8c79296370a85b65f6d0c8d7ff12a1b (diff)
Change default timeout from 5000 to 500 ms
Diffstat (limited to 'container-search/src/main/java/com/yahoo/search/Query.java')
-rw-r--r--container-search/src/main/java/com/yahoo/search/Query.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/container-search/src/main/java/com/yahoo/search/Query.java b/container-search/src/main/java/com/yahoo/search/Query.java
index bf0920a2aa5..e1bfc96dab0 100644
--- a/container-search/src/main/java/com/yahoo/search/Query.java
+++ b/container-search/src/main/java/com/yahoo/search/Query.java
@@ -139,7 +139,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
// The timeout to be used when dumping rank features
private static final long dumpTimeout = (6 * 60 * 1000); // 6 minutes
- private static final long defaultTimeout = 5000;
+ private static final long defaultTimeout = 500;
/** The timeout of the query, in milliseconds */
private long timeout = defaultTimeout;
@@ -537,7 +537,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
/**
* Returns the number of milliseconds to wait for a response from a search backend
* before timing it out. Default is 5000.
* <p>
* Note: If Ranking.RANKFEATURES is turned on, this is hardcoded to 6 minutes.
*
@@ -549,7 +549,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
/**
* Sets the number of milliseconds to wait for a response from a search backend
* before time out. Default is 5000.
*/
public void setTimeout(long timeout) {
if (timeout > 1000000000 || timeout < 0)
@@ -885,7 +885,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
yql.append(" limit ").append(Integer.toString(getHits()));
}
}
- if (getTimeout() != 5000L) {
+ if (getTimeout() != defaultTimeout) {
yql.append(" timeout ").append(Long.toString(getTimeout()));
}
yql.append(';');
@@ -537,7 +537,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
/**
* Returns the number of milliseconds to wait for a response from a search backend
- * before timing it out. Default is 5000.
+ * before timing it out. Default is 500.
* <p>
* Note: If Ranking.RANKFEATURES is turned on, this is hardcoded to 6 minutes.
@@ -549,7 +549,7 @@ public class Query extends com.yahoo.processing.Request implements Cloneable {
/**
* Sets the number of milliseconds to wait for a response from a search backend
- * before time out. Default is 5000.
+ * before time out. Default is 500.
*/
public void setTimeout(long timeout) {